Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: pkg/analyzer/test/generated/constant_test.dart

Issue 1643253002: Make constant map literal ordered. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/test/generated/all_the_rest_test.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/test/generated/constant_test.dart
diff --git a/pkg/analyzer/test/generated/constant_test.dart b/pkg/analyzer/test/generated/constant_test.dart
index 08e4add56ac20eb3e6ba34e2f8ac31d381acbbfb..f82c31edbc596329840ee2df488b46c4857da10d 100644
--- a/pkg/analyzer/test/generated/constant_test.dart
+++ b/pkg/analyzer/test/generated/constant_test.dart
@@ -284,6 +284,8 @@ class ConstantEvaluatorTest extends ResolverTestCase {
EvaluationResult result =
_getExpressionValue("const {'a' : 'm', 'b' : 'n', 'c' : 'o'}");
expect(result.isValid, isTrue);
+ Map<DartObject, DartObject> map = result.value.toMapValue();
+ expect(map.keys.map((k) => k.toStringValue()), ['a', 'b', 'c']);
}
void test_literal_null() {
@@ -834,7 +836,7 @@ class C {
_evaluateAnnotation(compilationUnit, "C", "f");
}
- void test_annotation_toplevelVariable() {
+ void test_annotation_topLevelVariable() {
CompilationUnit compilationUnit = resolveSource(r'''
const int i = 5;
class C {
@@ -847,8 +849,8 @@ class C {
expect(_assertValidInt(result), 5);
}
- void test_annotation_toplevelVariable_args() {
- // Applying arguments to an annotation that is a toplevel variable is
+ void test_annotation_topLevelVariable_args() {
+ // Applying arguments to an annotation that is a top-level variable is
// illegal, but shouldn't crash analysis.
CompilationUnit compilationUnit = resolveSource(r'''
const int i = 5;
@@ -1377,7 +1379,7 @@ class B {
_assertIntField(fields, "k", 7);
}
- void test_instanceCreationExpression_computedField_usesToplevelConst() {
+ void test_instanceCreationExpression_computedField_usesTopLevelConst() {
CompilationUnit compilationUnit = resolveSource(r'''
const foo = const A(3);
const bar = 4;
@@ -1585,7 +1587,7 @@ class A {
_assertValidUnknown(_evaluateTopLevelVariable(compilationUnit, "foo"));
}
- void test_instanceCreationExpression_redirect_extern() {
+ void test_instanceCreationExpression_redirect_external() {
CompilationUnit compilationUnit = resolveSource(r'''
const foo = const A();
class A {
« no previous file with comments | « pkg/analyzer/test/generated/all_the_rest_test.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698